import sys
sys.path.append('.')
import pyDH

def test_pydh_keygen():
    d1 = pyDH.DiffieHellman()
    d2 = pyDH.DiffieHellman()
    d1_pubkey = d1.gen_public_key()
    d2_pubkey = d2.gen_public_key()
    d1_sharedkey = d1.gen_shared_key(d2_pubkey)
    d2_sharedkey = d2.gen_shared_key(d1_pubkey)
    assert d1_sharedkey == d2_sharedkey




from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
  name = 'pyDH',
  packages = ['pyDH'],
  version = '0.1.6',
  license = 'Apache',
  description = 'Pure Python Implementation of Diffie-Hellman Key Exchange',
  long_description=long_description,
  long_description_content_type='text/markdown',
  author = 'Amirali Sanatinia',
  author_email = 'amirali@ccs.neu.edu',
  url = 'https://github.com/amiralis/pyDH',
  keywords = ['crypto', 'Diffie Hellman', 'Key Exchange'],
  classifiers = [
    	'License :: OSI Approved :: Apache Software License',
    	'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
		'Topic :: Security :: Cryptography',
		],
)
